# Generated by Django 3.2.9 on 2022-02-07 13:35

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_notifications", "0003_auto_20220207_1157"),
    ]

    operations = [
        migrations.AddField(
            model_name="notification",
            name="from_email",
            field=models.EmailField(
                default="evenements@ville-tourcoing.fr",
                help_text="Email address to use as sender",
                max_length=254,
                verbose_name="From email",
            ),
        ),
    ]
