# Generated by Django 3.2.12 on 2022-03-31 09:12

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("django_notifications", "0004_notification_from_email"),
    ]

    operations = [
        migrations.AddField(
            model_name="notificationconfig",
            name="debug_notifications_email",
            field=models.EmailField(
                blank=True,
                help_text="Email to send the notification copies to.",
                max_length=254,
                default="",
                verbose_name="Debug notifications email",
            ),
        ),
        migrations.AddField(
            model_name="notificationconfig",
            name="enable_debug_notifications",
            field=models.BooleanField(
                default=False,
                help_text="If enabled, notification copies will be sent to the provided email.",
                verbose_name="Enable debug notifications",
            ),
        ),
    ]
