# Generated by Django 3.2.9 on 2022-02-07 10:57

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_notifications', '0002_notificationconfig'),
    ]

    operations = [
        migrations.AlterField(
            model_name='notificationconfig',
            name='receive_messages_field',
            field=models.CharField(default='userprofile.receive_messages', help_text="Champs à vérifier sur le profil utilisateur pour valider si l'utilisateur souhaite recevoir les messages.", max_length=255, verbose_name='Nom du champs bloquant les messages'),
        ),
        migrations.AlterField(
            model_name='notificationconfig',
            name='receive_notifications_field',
            field=models.CharField(default='userprofile.receive_notifications', help_text="Champs à vérifier sur le profil utilisateur pour valider si l'utilisateur souhaite recevoir les notifications.", max_length=255, verbose_name='Nom du champs bloquant les notifications'),
        ),
    ]
